/* Generated by re2c 0.13.5 on Sun Nov 15 18:20:06 2009 */
#line 1 "optint.re2c"
#include "pabidecl.h"
#include "pabstract.h"
#include "pparam.h"
#include "pconst.h"

API_IMPL 
int
APICALL
tmplpro_get_int_option(struct tmplpro_param* param, const char *p, int* failure_ptr)
{
	register const char* YYMARKER;
	param->htp_errno = 0;
	if (failure_ptr) *failure_ptr=0;

#line 18 "<stdout>"
	{
		unsigned char yych;

		yych = (unsigned char)*p;
		switch (yych) {
		case 'd':	goto yy5;
		case 'f':	goto yy10;
		case 'g':	goto yy2;
		case 'l':	goto yy8;
		case 'm':	goto yy4;
		case 'n':	goto yy7;
		case 'p':	goto yy11;
		case 's':	goto yy9;
		case 't':	goto yy6;
		default:	goto yy12;
		}
yy2:
		yych = (unsigned char)*(YYMARKER = ++p);
		switch (yych) {
		case 'l':	goto yy144;
		default:	goto yy3;
		}
yy3:
#line 32 "optint.re2c"
		{if (failure_ptr) *failure_ptr=ERR_PRO_INVALID_ARGUMENT; param->htp_errno=ERR_PRO_INVALID_ARGUMENT; return 0;}
#line 44 "<stdout>"
yy4:
		yych = (unsigned char)*(YYMARKER = ++p);
		switch (yych) {
		case 'a':	goto yy132;
		default:	goto yy3;
		}
yy5:
		yych = (unsigned char)*(YYMARKER = ++p);
		switch (yych) {
		case 'e':	goto yy114;
		default:	goto yy3;
		}
yy6:
		yych = (unsigned char)*(YYMARKER = ++p);
		switch (yych) {
		case 'm':	goto yy101;
		default:	goto yy3;
		}
yy7:
		yych = (unsigned char)*(YYMARKER = ++p);
		switch (yych) {
		case 'o':	goto yy90;
		default:	goto yy3;
		}
yy8:
		yych = (unsigned char)*(YYMARKER = ++p);
		switch (yych) {
		case 'o':	goto yy73;
		default:	goto yy3;
		}
yy9:
		yych = (unsigned char)*(YYMARKER = ++p);
		switch (yych) {
		case 'e':	goto yy45;
		case 't':	goto yy46;
		default:	goto yy3;
		}
yy10:
		yych = (unsigned char)*(YYMARKER = ++p);
		switch (yych) {
		case 'i':	goto yy38;
		default:	goto yy3;
		}
yy11:
		yych = (unsigned char)*(YYMARKER = ++p);
		switch (yych) {
		case 'a':	goto yy13;
		default:	goto yy3;
		}
yy12:
		yych = (unsigned char)*++p;
		goto yy3;
yy13:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 't':	goto yy15;
		default:	goto yy14;
		}
yy14:
		p = YYMARKER;
		goto yy3;
yy15:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'h':	goto yy16;
		default:	goto yy14;
		}
yy16:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy17;
		default:	goto yy14;
		}
yy17:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'l':	goto yy18;
		default:	goto yy14;
		}
yy18:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'i':	goto yy19;
		default:	goto yy14;
		}
yy19:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'k':	goto yy20;
		default:	goto yy14;
		}
yy20:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy21;
		default:	goto yy14;
		}
yy21:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy22;
		default:	goto yy14;
		}
yy22:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'v':	goto yy23;
		default:	goto yy14;
		}
yy23:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy24;
		default:	goto yy14;
		}
yy24:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'r':	goto yy25;
		default:	goto yy14;
		}
yy25:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'i':	goto yy26;
		default:	goto yy14;
		}
yy26:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy27;
		default:	goto yy14;
		}
yy27:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'b':	goto yy28;
		default:	goto yy14;
		}
yy28:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'l':	goto yy29;
		default:	goto yy14;
		}
yy29:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy30;
		default:	goto yy14;
		}
yy30:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy31;
		default:	goto yy14;
		}
yy31:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 's':	goto yy32;
		default:	goto yy14;
		}
yy32:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'c':	goto yy33;
		default:	goto yy14;
		}
yy33:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'o':	goto yy34;
		default:	goto yy14;
		}
yy34:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'p':	goto yy35;
		default:	goto yy14;
		}
yy35:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy36;
		default:	goto yy14;
		}
yy36:
		++p;
#line 29 "optint.re2c"
		{return (int) param->path_like_variable_scope;}
#line 236 "<stdout>"
yy38:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'l':	goto yy39;
		default:	goto yy14;
		}
yy39:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 't':	goto yy40;
		default:	goto yy14;
		}
yy40:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy41;
		default:	goto yy14;
		}
yy41:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'r':	goto yy42;
		default:	goto yy14;
		}
yy42:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 's':	goto yy43;
		default:	goto yy14;
		}
yy43:
		++p;
#line 27 "optint.re2c"
		{return (int) param->filters;}
#line 271 "<stdout>"
yy45:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy52;
		default:	goto yy14;
		}
yy46:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'r':	goto yy47;
		default:	goto yy14;
		}
yy47:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'i':	goto yy48;
		default:	goto yy14;
		}
yy48:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'c':	goto yy49;
		default:	goto yy14;
		}
yy49:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 't':	goto yy50;
		default:	goto yy14;
		}
yy50:
		++p;
#line 26 "optint.re2c"
		{return (int) param->strict;}
#line 306 "<stdout>"
yy52:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'r':	goto yy53;
		default:	goto yy14;
		}
yy53:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'c':	goto yy54;
		default:	goto yy14;
		}
yy54:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'h':	goto yy55;
		default:	goto yy14;
		}
yy55:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy56;
		default:	goto yy14;
		}
yy56:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'p':	goto yy57;
		default:	goto yy14;
		}
yy57:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy58;
		default:	goto yy14;
		}
yy58:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 't':	goto yy59;
		default:	goto yy14;
		}
yy59:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'h':	goto yy60;
		default:	goto yy14;
		}
yy60:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy61;
		default:	goto yy14;
		}
yy61:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'o':	goto yy62;
		default:	goto yy14;
		}
yy62:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'n':	goto yy63;
		default:	goto yy14;
		}
yy63:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy64;
		default:	goto yy14;
		}
yy64:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'i':	goto yy65;
		default:	goto yy14;
		}
yy65:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'n':	goto yy66;
		default:	goto yy14;
		}
yy66:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'c':	goto yy67;
		default:	goto yy14;
		}
yy67:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'l':	goto yy68;
		default:	goto yy14;
		}
yy68:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'u':	goto yy69;
		default:	goto yy14;
		}
yy69:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'd':	goto yy70;
		default:	goto yy14;
		}
yy70:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy71;
		default:	goto yy14;
		}
yy71:
		++p;
#line 30 "optint.re2c"
		{return (int) param->search_path_on_include;}
#line 425 "<stdout>"
yy73:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'o':	goto yy74;
		default:	goto yy14;
		}
yy74:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'p':	goto yy75;
		default:	goto yy14;
		}
yy75:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy76;
		default:	goto yy14;
		}
yy76:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'c':	goto yy77;
		default:	goto yy14;
		}
yy77:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'o':	goto yy78;
		default:	goto yy14;
		}
yy78:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'n':	goto yy79;
		default:	goto yy14;
		}
yy79:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 't':	goto yy80;
		default:	goto yy14;
		}
yy80:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy81;
		default:	goto yy14;
		}
yy81:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'x':	goto yy82;
		default:	goto yy14;
		}
yy82:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 't':	goto yy83;
		default:	goto yy14;
		}
yy83:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy84;
		default:	goto yy14;
		}
yy84:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'v':	goto yy85;
		default:	goto yy14;
		}
yy85:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy86;
		default:	goto yy14;
		}
yy86:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'r':	goto yy87;
		default:	goto yy14;
		}
yy87:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 's':	goto yy88;
		default:	goto yy14;
		}
yy88:
		++p;
#line 25 "optint.re2c"
		{return (int) param->loop_context_vars;}
#line 520 "<stdout>"
yy90:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy91;
		default:	goto yy14;
		}
yy91:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'i':	goto yy92;
		default:	goto yy14;
		}
yy92:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'n':	goto yy93;
		default:	goto yy14;
		}
yy93:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'c':	goto yy94;
		default:	goto yy14;
		}
yy94:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'l':	goto yy95;
		default:	goto yy14;
		}
yy95:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'u':	goto yy96;
		default:	goto yy14;
		}
yy96:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'd':	goto yy97;
		default:	goto yy14;
		}
yy97:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy98;
		default:	goto yy14;
		}
yy98:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 's':	goto yy99;
		default:	goto yy14;
		}
yy99:
		++p;
#line 24 "optint.re2c"
		{return (int) param->no_includes;}
#line 579 "<stdout>"
yy101:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'p':	goto yy102;
		default:	goto yy14;
		}
yy102:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'l':	goto yy103;
		default:	goto yy14;
		}
yy103:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy104;
		default:	goto yy14;
		}
yy104:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'v':	goto yy105;
		default:	goto yy14;
		}
yy105:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy106;
		default:	goto yy14;
		}
yy106:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'r':	goto yy107;
		default:	goto yy14;
		}
yy107:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy108;
		default:	goto yy14;
		}
yy108:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'c':	goto yy109;
		default:	goto yy14;
		}
yy109:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy110;
		default:	goto yy14;
		}
yy110:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 's':	goto yy111;
		default:	goto yy14;
		}
yy111:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy112;
		default:	goto yy14;
		}
yy112:
		++p;
#line 23 "optint.re2c"
		{return param->tmpl_var_case;}
#line 650 "<stdout>"
yy114:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'b':	goto yy115;
		case 'f':	goto yy116;
		default:	goto yy14;
		}
yy115:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'u':	goto yy129;
		default:	goto yy14;
		}
yy116:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy117;
		default:	goto yy14;
		}
yy117:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'u':	goto yy118;
		default:	goto yy14;
		}
yy118:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'l':	goto yy119;
		default:	goto yy14;
		}
yy119:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 't':	goto yy120;
		default:	goto yy14;
		}
yy120:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy121;
		default:	goto yy14;
		}
yy121:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy122;
		default:	goto yy14;
		}
yy122:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 's':	goto yy123;
		default:	goto yy14;
		}
yy123:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'c':	goto yy124;
		default:	goto yy14;
		}
yy124:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy125;
		default:	goto yy14;
		}
yy125:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'p':	goto yy126;
		default:	goto yy14;
		}
yy126:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy127;
		default:	goto yy14;
		}
yy127:
		++p;
#line 28 "optint.re2c"
		{return param->default_escape;}
#line 734 "<stdout>"
yy129:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'g':	goto yy130;
		default:	goto yy14;
		}
yy130:
		++p;
#line 22 "optint.re2c"
		{return param->debug;}
#line 745 "<stdout>"
yy132:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'x':	goto yy133;
		default:	goto yy14;
		}
yy133:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy134;
		default:	goto yy14;
		}
yy134:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'i':	goto yy135;
		default:	goto yy14;
		}
yy135:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'n':	goto yy136;
		default:	goto yy14;
		}
yy136:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'c':	goto yy137;
		default:	goto yy14;
		}
yy137:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'l':	goto yy138;
		default:	goto yy14;
		}
yy138:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'u':	goto yy139;
		default:	goto yy14;
		}
yy139:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'd':	goto yy140;
		default:	goto yy14;
		}
yy140:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy141;
		default:	goto yy14;
		}
yy141:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 's':	goto yy142;
		default:	goto yy14;
		}
yy142:
		++p;
#line 21 "optint.re2c"
		{return param->max_includes;}
#line 810 "<stdout>"
yy144:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'o':	goto yy145;
		default:	goto yy14;
		}
yy145:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'b':	goto yy146;
		default:	goto yy14;
		}
yy146:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy147;
		default:	goto yy14;
		}
yy147:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'l':	goto yy148;
		default:	goto yy14;
		}
yy148:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy149;
		default:	goto yy14;
		}
yy149:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'v':	goto yy150;
		default:	goto yy14;
		}
yy150:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy151;
		default:	goto yy14;
		}
yy151:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'r':	goto yy152;
		default:	goto yy14;
		}
yy152:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 's':	goto yy153;
		default:	goto yy14;
		}
yy153:
		++p;
#line 20 "optint.re2c"
		{return param->global_vars;}
#line 869 "<stdout>"
	}
#line 33 "optint.re2c"

}

API_IMPL 
int
APICALL
tmplpro_set_int_option(struct tmplpro_param* param, const char *p, int val)
{
	register const char* YYMARKER;
	param->htp_errno = 0;

#line 883 "<stdout>"
	{
		unsigned char yych;
		yych = (unsigned char)*p;
		switch (yych) {
		case 'd':	goto yy160;
		case 'f':	goto yy165;
		case 'g':	goto yy157;
		case 'l':	goto yy163;
		case 'm':	goto yy159;
		case 'n':	goto yy162;
		case 'p':	goto yy166;
		case 's':	goto yy164;
		case 't':	goto yy161;
		default:	goto yy167;
		}
yy157:
		yych = (unsigned char)*(YYMARKER = ++p);
		switch (yych) {
		case 'l':	goto yy299;
		default:	goto yy158;
		}
yy158:
#line 56 "optint.re2c"
		{param->htp_errno=ERR_PRO_INVALID_ARGUMENT; return ERR_PRO_INVALID_ARGUMENT;}
#line 908 "<stdout>"
yy159:
		yych = (unsigned char)*(YYMARKER = ++p);
		switch (yych) {
		case 'a':	goto yy287;
		default:	goto yy158;
		}
yy160:
		yych = (unsigned char)*(YYMARKER = ++p);
		switch (yych) {
		case 'e':	goto yy269;
		default:	goto yy158;
		}
yy161:
		yych = (unsigned char)*(YYMARKER = ++p);
		switch (yych) {
		case 'm':	goto yy256;
		default:	goto yy158;
		}
yy162:
		yych = (unsigned char)*(YYMARKER = ++p);
		switch (yych) {
		case 'o':	goto yy245;
		default:	goto yy158;
		}
yy163:
		yych = (unsigned char)*(YYMARKER = ++p);
		switch (yych) {
		case 'o':	goto yy228;
		default:	goto yy158;
		}
yy164:
		yych = (unsigned char)*(YYMARKER = ++p);
		switch (yych) {
		case 'e':	goto yy200;
		case 't':	goto yy201;
		default:	goto yy158;
		}
yy165:
		yych = (unsigned char)*(YYMARKER = ++p);
		switch (yych) {
		case 'i':	goto yy193;
		default:	goto yy158;
		}
yy166:
		yych = (unsigned char)*(YYMARKER = ++p);
		switch (yych) {
		case 'a':	goto yy168;
		default:	goto yy158;
		}
yy167:
		yych = (unsigned char)*++p;
		goto yy158;
yy168:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 't':	goto yy170;
		default:	goto yy169;
		}
yy169:
		p = YYMARKER;
		goto yy158;
yy170:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'h':	goto yy171;
		default:	goto yy169;
		}
yy171:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy172;
		default:	goto yy169;
		}
yy172:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'l':	goto yy173;
		default:	goto yy169;
		}
yy173:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'i':	goto yy174;
		default:	goto yy169;
		}
yy174:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'k':	goto yy175;
		default:	goto yy169;
		}
yy175:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy176;
		default:	goto yy169;
		}
yy176:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy177;
		default:	goto yy169;
		}
yy177:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'v':	goto yy178;
		default:	goto yy169;
		}
yy178:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy179;
		default:	goto yy169;
		}
yy179:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'r':	goto yy180;
		default:	goto yy169;
		}
yy180:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'i':	goto yy181;
		default:	goto yy169;
		}
yy181:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy182;
		default:	goto yy169;
		}
yy182:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'b':	goto yy183;
		default:	goto yy169;
		}
yy183:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'l':	goto yy184;
		default:	goto yy169;
		}
yy184:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy185;
		default:	goto yy169;
		}
yy185:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy186;
		default:	goto yy169;
		}
yy186:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 's':	goto yy187;
		default:	goto yy169;
		}
yy187:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'c':	goto yy188;
		default:	goto yy169;
		}
yy188:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'o':	goto yy189;
		default:	goto yy169;
		}
yy189:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'p':	goto yy190;
		default:	goto yy169;
		}
yy190:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy191;
		default:	goto yy169;
		}
yy191:
		++p;
#line 53 "optint.re2c"
		{param->path_like_variable_scope=(flag)val; return 0;}
#line 1100 "<stdout>"
yy193:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'l':	goto yy194;
		default:	goto yy169;
		}
yy194:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 't':	goto yy195;
		default:	goto yy169;
		}
yy195:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy196;
		default:	goto yy169;
		}
yy196:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'r':	goto yy197;
		default:	goto yy169;
		}
yy197:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 's':	goto yy198;
		default:	goto yy169;
		}
yy198:
		++p;
#line 51 "optint.re2c"
		{param->filters=(flag)val; return 0;}
#line 1135 "<stdout>"
yy200:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy207;
		default:	goto yy169;
		}
yy201:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'r':	goto yy202;
		default:	goto yy169;
		}
yy202:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'i':	goto yy203;
		default:	goto yy169;
		}
yy203:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'c':	goto yy204;
		default:	goto yy169;
		}
yy204:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 't':	goto yy205;
		default:	goto yy169;
		}
yy205:
		++p;
#line 50 "optint.re2c"
		{param->strict=(flag)val; return 0;}
#line 1170 "<stdout>"
yy207:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'r':	goto yy208;
		default:	goto yy169;
		}
yy208:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'c':	goto yy209;
		default:	goto yy169;
		}
yy209:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'h':	goto yy210;
		default:	goto yy169;
		}
yy210:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy211;
		default:	goto yy169;
		}
yy211:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'p':	goto yy212;
		default:	goto yy169;
		}
yy212:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy213;
		default:	goto yy169;
		}
yy213:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 't':	goto yy214;
		default:	goto yy169;
		}
yy214:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'h':	goto yy215;
		default:	goto yy169;
		}
yy215:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy216;
		default:	goto yy169;
		}
yy216:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'o':	goto yy217;
		default:	goto yy169;
		}
yy217:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'n':	goto yy218;
		default:	goto yy169;
		}
yy218:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy219;
		default:	goto yy169;
		}
yy219:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'i':	goto yy220;
		default:	goto yy169;
		}
yy220:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'n':	goto yy221;
		default:	goto yy169;
		}
yy221:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'c':	goto yy222;
		default:	goto yy169;
		}
yy222:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'l':	goto yy223;
		default:	goto yy169;
		}
yy223:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'u':	goto yy224;
		default:	goto yy169;
		}
yy224:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'd':	goto yy225;
		default:	goto yy169;
		}
yy225:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy226;
		default:	goto yy169;
		}
yy226:
		++p;
#line 54 "optint.re2c"
		{param->search_path_on_include=(flag)val; return 0;}
#line 1289 "<stdout>"
yy228:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'o':	goto yy229;
		default:	goto yy169;
		}
yy229:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'p':	goto yy230;
		default:	goto yy169;
		}
yy230:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy231;
		default:	goto yy169;
		}
yy231:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'c':	goto yy232;
		default:	goto yy169;
		}
yy232:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'o':	goto yy233;
		default:	goto yy169;
		}
yy233:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'n':	goto yy234;
		default:	goto yy169;
		}
yy234:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 't':	goto yy235;
		default:	goto yy169;
		}
yy235:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy236;
		default:	goto yy169;
		}
yy236:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'x':	goto yy237;
		default:	goto yy169;
		}
yy237:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 't':	goto yy238;
		default:	goto yy169;
		}
yy238:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy239;
		default:	goto yy169;
		}
yy239:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'v':	goto yy240;
		default:	goto yy169;
		}
yy240:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy241;
		default:	goto yy169;
		}
yy241:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'r':	goto yy242;
		default:	goto yy169;
		}
yy242:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 's':	goto yy243;
		default:	goto yy169;
		}
yy243:
		++p;
#line 49 "optint.re2c"
		{param->loop_context_vars=(flag)val; return 0;}
#line 1384 "<stdout>"
yy245:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy246;
		default:	goto yy169;
		}
yy246:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'i':	goto yy247;
		default:	goto yy169;
		}
yy247:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'n':	goto yy248;
		default:	goto yy169;
		}
yy248:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'c':	goto yy249;
		default:	goto yy169;
		}
yy249:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'l':	goto yy250;
		default:	goto yy169;
		}
yy250:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'u':	goto yy251;
		default:	goto yy169;
		}
yy251:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'd':	goto yy252;
		default:	goto yy169;
		}
yy252:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy253;
		default:	goto yy169;
		}
yy253:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 's':	goto yy254;
		default:	goto yy169;
		}
yy254:
		++p;
#line 48 "optint.re2c"
		{param->no_includes=(flag)val; return 0;}
#line 1443 "<stdout>"
yy256:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'p':	goto yy257;
		default:	goto yy169;
		}
yy257:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'l':	goto yy258;
		default:	goto yy169;
		}
yy258:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy259;
		default:	goto yy169;
		}
yy259:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'v':	goto yy260;
		default:	goto yy169;
		}
yy260:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy261;
		default:	goto yy169;
		}
yy261:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'r':	goto yy262;
		default:	goto yy169;
		}
yy262:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy263;
		default:	goto yy169;
		}
yy263:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'c':	goto yy264;
		default:	goto yy169;
		}
yy264:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy265;
		default:	goto yy169;
		}
yy265:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 's':	goto yy266;
		default:	goto yy169;
		}
yy266:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy267;
		default:	goto yy169;
		}
yy267:
		++p;
#line 47 "optint.re2c"
		{param->tmpl_var_case=val; return 0;}
#line 1514 "<stdout>"
yy269:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'b':	goto yy270;
		case 'f':	goto yy271;
		default:	goto yy169;
		}
yy270:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'u':	goto yy284;
		default:	goto yy169;
		}
yy271:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy272;
		default:	goto yy169;
		}
yy272:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'u':	goto yy273;
		default:	goto yy169;
		}
yy273:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'l':	goto yy274;
		default:	goto yy169;
		}
yy274:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 't':	goto yy275;
		default:	goto yy169;
		}
yy275:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy276;
		default:	goto yy169;
		}
yy276:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy277;
		default:	goto yy169;
		}
yy277:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 's':	goto yy278;
		default:	goto yy169;
		}
yy278:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'c':	goto yy279;
		default:	goto yy169;
		}
yy279:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy280;
		default:	goto yy169;
		}
yy280:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'p':	goto yy281;
		default:	goto yy169;
		}
yy281:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy282;
		default:	goto yy169;
		}
yy282:
		++p;
#line 52 "optint.re2c"
		{param->default_escape=val; return 0;}
#line 1598 "<stdout>"
yy284:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'g':	goto yy285;
		default:	goto yy169;
		}
yy285:
		++p;
#line 46 "optint.re2c"
		{param->debug=val; return 0;}
#line 1609 "<stdout>"
yy287:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'x':	goto yy288;
		default:	goto yy169;
		}
yy288:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy289;
		default:	goto yy169;
		}
yy289:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'i':	goto yy290;
		default:	goto yy169;
		}
yy290:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'n':	goto yy291;
		default:	goto yy169;
		}
yy291:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'c':	goto yy292;
		default:	goto yy169;
		}
yy292:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'l':	goto yy293;
		default:	goto yy169;
		}
yy293:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'u':	goto yy294;
		default:	goto yy169;
		}
yy294:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'd':	goto yy295;
		default:	goto yy169;
		}
yy295:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'e':	goto yy296;
		default:	goto yy169;
		}
yy296:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 's':	goto yy297;
		default:	goto yy169;
		}
yy297:
		++p;
#line 45 "optint.re2c"
		{param->max_includes=val; return 0;}
#line 1674 "<stdout>"
yy299:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'o':	goto yy300;
		default:	goto yy169;
		}
yy300:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'b':	goto yy301;
		default:	goto yy169;
		}
yy301:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy302;
		default:	goto yy169;
		}
yy302:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'l':	goto yy303;
		default:	goto yy169;
		}
yy303:
		yych = (unsigned char)*++p;
		switch (yych) {
		case '_':	goto yy304;
		default:	goto yy169;
		}
yy304:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'v':	goto yy305;
		default:	goto yy169;
		}
yy305:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'a':	goto yy306;
		default:	goto yy169;
		}
yy306:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 'r':	goto yy307;
		default:	goto yy169;
		}
yy307:
		yych = (unsigned char)*++p;
		switch (yych) {
		case 's':	goto yy308;
		default:	goto yy169;
		}
yy308:
		++p;
#line 44 "optint.re2c"
		{param->global_vars=val; return 0;}
#line 1733 "<stdout>"
	}
#line 57 "optint.re2c"

}

static
void _reset_int_options_set_zero_defaults(struct tmplpro_param* param)
{
	param->global_vars=0;
	param->debug=0;
	param->tmpl_var_case=0;
	param->no_includes=(flag)0;
	param->loop_context_vars=(flag)0;
	param->strict=(flag)0;
	param->filters=(flag)0;
	param->default_escape=0;
	param->path_like_variable_scope=(flag)0;
	param->search_path_on_include=(flag)0;

}

TMPLPRO_LOCAL
void _reset_int_options_set_nonzero_defaults(struct tmplpro_param* param)
{
	param->max_includes=16;

}

API_IMPL 
void
APICALL
tmplpro_reset_int_options(struct tmplpro_param* param)
{
	_reset_int_options_set_zero_defaults(param);
	_reset_int_options_set_nonzero_defaults(param);
}

/*
 * Local variables:
 * mode: c
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */
